Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(877)

Unified Diff: chrome/browser/extensions/api/settings_private/settings_private_api.h

Issue 2430463002: MD Settings: tweak some chrome.settingsPrivate method names (Closed)
Patch Set: histograms.xml Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/extensions/api/settings_private/settings_private_api.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/extensions/api/settings_private/settings_private_api.h
diff --git a/chrome/browser/extensions/api/settings_private/settings_private_api.h b/chrome/browser/extensions/api/settings_private/settings_private_api.h
index 07a03ece7f65a0af0edd466e16a8ed2fa82d58e0..e61e09a458a0f90d21b7ede413a0446eb9da8ab4 100644
--- a/chrome/browser/extensions/api/settings_private/settings_private_api.h
+++ b/chrome/browser/extensions/api/settings_private/settings_private_api.h
@@ -60,38 +60,38 @@ class SettingsPrivateGetPrefFunction : public UIThreadExtensionFunction {
DISALLOW_COPY_AND_ASSIGN(SettingsPrivateGetPrefFunction);
};
-// Implements the chrome.settingsPrivate.getDefaultZoomPercent method.
-class SettingsPrivateGetDefaultZoomPercentFunction
+// Implements the chrome.settingsPrivate.getDefaultZoom method.
+class SettingsPrivateGetDefaultZoomFunction
: public UIThreadExtensionFunction {
public:
- SettingsPrivateGetDefaultZoomPercentFunction() {}
- DECLARE_EXTENSION_FUNCTION("settingsPrivate.getDefaultZoomPercent",
- SETTINGSPRIVATE_GETDEFAULTZOOMPERCENTFUNCTION);
+ SettingsPrivateGetDefaultZoomFunction() {}
+ DECLARE_EXTENSION_FUNCTION("settingsPrivate.getDefaultZoom",
+ SETTINGSPRIVATE_GETDEFAULTZOOMFUNCTION);
protected:
- ~SettingsPrivateGetDefaultZoomPercentFunction() override;
+ ~SettingsPrivateGetDefaultZoomFunction() override;
// AsyncExtensionFunction overrides.
ResponseAction Run() override;
- DISALLOW_COPY_AND_ASSIGN(SettingsPrivateGetDefaultZoomPercentFunction);
+ DISALLOW_COPY_AND_ASSIGN(SettingsPrivateGetDefaultZoomFunction);
};
-// Implements the chrome.settingsPrivate.setDefaultZoomPercent method.
-class SettingsPrivateSetDefaultZoomPercentFunction
+// Implements the chrome.settingsPrivate.setDefaultZoom method.
+class SettingsPrivateSetDefaultZoomFunction
: public UIThreadExtensionFunction {
public:
- SettingsPrivateSetDefaultZoomPercentFunction() {}
- DECLARE_EXTENSION_FUNCTION("settingsPrivate.setDefaultZoomPercent",
- SETTINGSPRIVATE_SETDEFAULTZOOMPERCENTFUNCTION);
+ SettingsPrivateSetDefaultZoomFunction() {}
+ DECLARE_EXTENSION_FUNCTION("settingsPrivate.setDefaultZoom",
+ SETTINGSPRIVATE_SETDEFAULTZOOMFUNCTION);
protected:
- ~SettingsPrivateSetDefaultZoomPercentFunction() override;
+ ~SettingsPrivateSetDefaultZoomFunction() override;
// AsyncExtensionFunction overrides.
ResponseAction Run() override;
- DISALLOW_COPY_AND_ASSIGN(SettingsPrivateSetDefaultZoomPercentFunction);
+ DISALLOW_COPY_AND_ASSIGN(SettingsPrivateSetDefaultZoomFunction);
};
} // namespace extensions
« no previous file with comments | « no previous file | chrome/browser/extensions/api/settings_private/settings_private_api.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698